@@ -41,11 +41,8 @@
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
-#include <rpc/types.h>
-#include <rpc/xdr.h>
-#include <rpc/auth.h>
+#include <rpc/rpc.h>
 #include <rpc/auth_gss.h>
-#include <rpc/clnt.h>
 #include <netinet/in.h>
 #include <gssapi/gssapi.h>
 
